==> kubernetes-model-kustomize-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/FieldOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FieldOptionsFluent<A extends FieldOptionsFluent<A>> extends BaseFluent<A>{
  public FieldOptionsFluent() {
  }
  public FieldOptionsFluent(FieldOptions instance) {
    instance = (instance != null ? instance : new FieldOptions());

    if (instance != null) {
      this.withCreate(instance.getCreate());
      this.withDelimiter(instance.getDelimiter());
      this.withEncoding(instance.getEncoding());
      this.withIndex(instance.getIndex());
      this.withCreate(instance.getCreate());
      this.withDelimiter(instance.getDelimiter());
      this.withEncoding(instance.getEncoding());
      this.withIndex(instance.getIndex());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Boolean create;
  private String delimiter;
  private String encoding;
  private Integer index;
  private Map<String,Object> additionalProperties;
  public Boolean getCreate() {
    return this.create;
  }
  public A withCreate(Boolean create) {
    this.create=create; return (A) this;
  }
  public boolean hasCreate() {
    return this.create != null;
  }
  public String getDelimiter() {
    return this.delimiter;
  }
  public A withDelimiter(String delimiter) {
    this.delimiter=delimiter; return (A) this;
  }
  public boolean hasDelimiter() {
    return this.delimiter != null;
  }
  public String getEncoding() {
    return this.encoding;
  }
  public A withEncoding(String encoding) {
    this.encoding=encoding; return (A) this;
  }
  public boolean hasEncoding() {
    return this.encoding != null;
  }
  public Integer getIndex() {
    return this.index;
  }
  public A withIndex(Integer index) {
    this.index=index; return (A) this;
  }
  public boolean hasIndex() {
    return this.index != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FieldOptionsFluent that = (FieldOptionsFluent) o;
    if (!java.util.Objects.equals(create, that.create)) return false;

    if (!java.util.Objects.equals(delimiter, that.delimiter)) return false;

    if (!java.util.Objects.equals(encoding, that.encoding)) return false;

    if (!java.util.Objects.equals(index, that.index)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(create,  delimiter,  encoding,  index,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (create != null) { sb.append("create:"); sb.append(create + ","); }
    if (delimiter != null) { sb.append("delimiter:"); sb.append(delimiter + ","); }
    if (encoding != null) { sb.append("encoding:"); sb.append(encoding + ","); }
    if (index != null) { sb.append("index:"); sb.append(index + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withCreate() {
    return withCreate(true);
  }
  
}

==> kubernetes-model-kustomize-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/FieldOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FieldOptionsFluent<A extends FieldOptionsFluent<A>> extends BaseFluent<A>{
  public FieldOptionsFluent() {
  }
  
  public FieldOptionsFluent(FieldOptions instance) {
    this.copyInstance(instance);
  }
  private Boolean create;
  private String delimiter;
  private String encoding;
  private Integer index;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(FieldOptions instance) {
    instance = (instance != null ? instance : new FieldOptions());
  
    if (instance != null) {
        this.withCreate(instance.getCreate());
        this.withDelimiter(instance.getDelimiter());
        this.withEncoding(instance.getEncoding());
        this.withIndex(instance.getIndex());
        this.withCreate(instance.getCreate());
        this.withDelimiter(instance.getDelimiter());
        this.withEncoding(instance.getEncoding());
        this.withIndex(instance.getIndex());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Boolean getCreate() {
    return this.create;
  }
  
  public A withCreate(Boolean create) {
    this.create=create; return (A) this;
  }
  
  public boolean hasCreate() {
    return this.create != null;
  }
  
  public String getDelimiter() {
    return this.delimiter;
  }
  
  public A withDelimiter(String delimiter) {
    this.delimiter=delimiter; return (A) this;
  }
  
  public boolean hasDelimiter() {
    return this.delimiter != null;
  }
  
  public String getEncoding() {
    return this.encoding;
  }
  
  public A withEncoding(String encoding) {
    this.encoding=encoding; return (A) this;
  }
  
  public boolean hasEncoding() {
    return this.encoding != null;
  }
  
  public Integer getIndex() {
    return this.index;
  }
  
  public A withIndex(Integer index) {
    this.index=index; return (A) this;
  }
  
  public boolean hasIndex() {
    return this.index != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FieldOptionsFluent that = (FieldOptionsFluent) o;
    if (!java.util.Objects.equals(create, that.create)) return false;
  
    if (!java.util.Objects.equals(delimiter, that.delimiter)) return false;
  
    if (!java.util.Objects.equals(encoding, that.encoding)) return false;
  
    if (!java.util.Objects.equals(index, that.index)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(create,  delimiter,  encoding,  index,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (create != null) { sb.append("create:"); sb.append(create + ","); }
    if (delimiter != null) { sb.append("delimiter:"); sb.append(delimiter + ","); }
    if (encoding != null) { sb.append("encoding:"); sb.append(encoding + ","); }
    if (index != null) { sb.append("index:"); sb.append(index + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withCreate() {
    return withCreate(true);
  }
  

}
